/************************************ <lalVerbatim file="PrintFrequencySeriesCV">
Author: J.T. Whelan
$Id: PrintFrequencySeries.m4,v 1.2 2000/12/20 22:33:59 jolien Exp $
************************************* </lalVerbatim> */

/* <lalLaTeX>

\subsection{Module \texttt{PrintFrequencySeries.c}}
\label{ss:PrintFrequencySeries.c}

Print a $\langle\mbox{datatype}\rangle$FrequencySeries object into a
file.  For use in non-production and test code only.

\subsubsection*{Prototypes}
\vspace{0.1in}
\input{PrintFrequencySeriesCP}
\index{\texttt{LALZPrintFrequencySeries()}}
\index{\texttt{LALCPrintFrequencySeries()}}
\index{\texttt{LALDPrintFrequencySeries()}}
\index{\texttt{LALSPrintFrequencySeries()}}
\index{\texttt{LALI2PrintFrequencySeries()}}
\index{\texttt{LALI4PrintFrequencySeries()}}
\index{\texttt{LALI8PrintFrequencySeries()}}
\index{\texttt{LALU2PrintFrequencySeries()}}
\index{\texttt{LALU4PrintFrequencySeries()}}
\index{\texttt{LALU8PrintFrequencySeries()}}
\index{\texttt{LALPrintFrequencySeries()}}

\subsubsection*{Description}

Each member of this family of functions prints the elements of
$\langle\mbox{datatype}\rangle$\verb+FrequencySeries+ into a file.
Note: the file name is specified using a character string.  This
function is for debugging use only: its arguments do not conform to
LAL standards so it should not be used in any real analysis codes.

\subsubsection*{Algorithm}

\subsubsection*{Uses}

\subsubsection*{Notes}


This function's arguments do not conform to the LAL spec.  For this
reason it should only be used for debugging purposes in test
functions, not in any production code.

Additionally, since printf cannot handle INT8 as integers, the
functions \verb&LALI8PrintFrequencySeries()& and
\verb&LALU8PrintFrequencySeries()& use a typecast to REAL8 and are
thus only valid for numbers between around $-10^{15}$ and $10^{15}$.

The output  is two or four space-separated columns: the first
column is the frequency in hertz corresponfing to the row in question;
for real and integer frequency series, the second column is the value
of the series; for complex time series, the second column is the real
part and the third the imaginary part of the value.

\vfill{\footnotesize\input{PrintFrequencySeriesCV}}

</lalLaTeX> */


#include "LALStdlib.h"
#include <stdio.h>
#include "LALDatatypes.h"
#include "PrintFTSeries.h"

/* <lalVerbatim file="PrintFrequencySeriesNRCSID"> */
NRCSID( PRINTFREQUENCYSERIESC, "$Id: PrintFrequencySeries.m4,v 1.2 2000/12/20 22:33:59 jolien Exp $" );
/* </lalVerbatim> */






























/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALZPrintFrequencySeries ( COMPLEX16FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  COMPLEX16 *data;
  FILE *fp;
  COMPLEX16 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a COMPLEX16Sequence */
  /* series->data->data is a pointer to COMPLEX16 */

  /* Make a COMPLEX16 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %g %g\n",f,data->re,data->im);
  }	

  fclose(fp);

  return;
}































/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALCPrintFrequencySeries ( COMPLEX8FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  COMPLEX8 *data;
  FILE *fp;
  COMPLEX8 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a COMPLEX8Sequence */
  /* series->data->data is a pointer to COMPLEX8 */

  /* Make a COMPLEX8 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %g %g\n",f,data->re,data->im);
  }	

  fclose(fp);

  return;
}































/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALDPrintFrequencySeries ( REAL8FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  REAL8 *data;
  FILE *fp;
  REAL8 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a REAL8Sequence */
  /* series->data->data is a pointer to REAL8 */

  /* Make a REAL8 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %g\n",f,*data);
  }	

  fclose(fp);

  return;
}































/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALSPrintFrequencySeries ( REAL4FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  REAL4 *data;
  FILE *fp;
  REAL4 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a REAL4Sequence */
  /* series->data->data is a pointer to REAL4 */

  /* Make a REAL4 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %g\n",f,*data);
  }	

  fclose(fp);

  return;
}































/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALI2PrintFrequencySeries ( INT2FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  INT2 *data;
  FILE *fp;
  INT2 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a INT2Sequence */
  /* series->data->data is a pointer to INT2 */

  /* Make a INT2 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %i\n",f,*data);
  }	

  fclose(fp);

  return;
}































/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALI4PrintFrequencySeries ( INT4FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  INT4 *data;
  FILE *fp;
  INT4 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a INT4Sequence */
  /* series->data->data is a pointer to INT4 */

  /* Make a INT4 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %i\n",f,*data);
  }	

  fclose(fp);

  return;
}































/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALI8PrintFrequencySeries ( INT8FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  INT8 *data;
  FILE *fp;
  INT8 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a INT8Sequence */
  /* series->data->data is a pointer to INT8 */

  /* Make a INT8 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %0.0f\n",f,(REAL8) *data);
  }	

  fclose(fp);

  return;
}

/* Note that LALI8PrintFrequencySeries does a typecast to REAL8 and is thus
 * inaccurate for numbers >~ 1e15 
 */






























/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALU2PrintFrequencySeries ( UINT2FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  UINT2 *data;
  FILE *fp;
  UINT2 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a UINT2Sequence */
  /* series->data->data is a pointer to UINT2 */

  /* Make a UINT2 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %i\n",f,*data);
  }	

  fclose(fp);

  return;
}































/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALU4PrintFrequencySeries ( UINT4FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  UINT4 *data;
  FILE *fp;
  UINT4 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a UINT4Sequence */
  /* series->data->data is a pointer to UINT4 */

  /* Make a UINT4 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %i\n",f,*data);
  }	

  fclose(fp);

  return;
}































/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALU8PrintFrequencySeries ( UINT8FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  UINT8 *data;
  FILE *fp;
  UINT8 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a UINT8Sequence */
  /* series->data->data is a pointer to UINT8 */

  /* Make a UINT8 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %0.0f\n",f,(REAL8) *data);
  }	

  fclose(fp);

  return;
}

/* Note that LALU8PrintFrequencySeries does a typecast to REAL8 and is thus
 * inaccurate for numbers >~ 1e15 
 */






























/* <lalVerbatim file="PrintFrequencySeriesCP"> */
void LALPrintFrequencySeries ( REAL4FrequencySeries *series, const CHAR *filename ) 
{ /* </lalVerbatim> */
  REAL8 f;
  REAL4 *data;
  FILE *fp;
  REAL4 *endOfSeq;

  if (series==NULL) return;

  /* *(series->data) is a REAL4Sequence */
  /* series->data->data is a pointer to REAL4 */

  /* Make a REAL4 pointer which points to the first memory address not
   * belonging to the sequence
   */

  endOfSeq = series->data->data + series->data->length;

  /* open output file */
  fp=fopen(filename,"w");
  for ( f = series->f0, data = series->data->data;
        data < endOfSeq;
        f += series->deltaF, ++data )
  {
    fprintf(fp,"%g %f\n",f,*data);
  }	

  fclose(fp);

  return;
}

